package Pcore::DBD::Builder::Pg;

use Pcore -class;

extends qw[Pcore::DBD::Builder];

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::DBD::Builder::Pg

=head1 SYNOPSIS

=head1 DESCRIPTION

=cut
